<?php 
/**
 * DbM Framework (PHP MVC Simple CMS)
 * All code copyright Design by Malina
 * DbM: www.dbm.org.pl
 */

class userController extends frameworkClass {
	
	public function __construct() {
		if (!$this->getSession('userId')) {
			$this->redirect("login.html");
		}
		
		$this->helper("application");
		$this->userModel = $this->model('userModel');
    }
	
	public function index() {
		$id = $this->getSession('userId');
		$result = $this->userModel->getUserAccount($id);
		
		if ($result['status'] === 'userNotFound') {
			//$this->setFlash("messageDanger", "SQL Query error! Data not found.");
			//$this->view("login");
			$this->redirect("login.html");
		}
		else {
			$userLogin = $result['data']->login;
			$this->setFlash("messageInfo", "Welcome ".$userLogin."! You are logged in.");
			$this->view("user", $result);
		}
	}
	
	public function profileMethod() {
		$this->redirect("user.html");
	}
	
	public function articleManageMethod() {
		$id = $this->getSession('userId');
		$result = $this->userModel->getPostData($id);
		
		$this->view("article_manage", $result);
	}
	
	public function articleAddMethod() {
		$this->view("article_add");
	}
	
	public function articleInsertMethod() {
		$user_id = $this->getSession('userId');
		
		$data = [
			'user_id'          => $user_id,
			'section_id'       => $this->input('dbm_section'),
			'header'           => $this->input('dbm_header'),
			'content'          => $this->inputHtml('dbm_content'),
			'errorSection'     => '',
			'errorHeader'      => '',
			'errorContent'     => ''
		];
		
		if (empty($data['section_id'])) {
			$data['errorSection'] = "Select article category!";
		}
		if (empty($data['header'])) {
			$data['errorHeader'] = "Header is required!";
		}
		if (empty($data['content'])) {
			$data['errorContent'] = "Content is required!";
		}
		
		if (empty($data['errorSection']) && empty($data['errorHeader']) && empty($data['errorContent'])) {
			$insert = [$data['user_id'], $data['section_id'], $data['header'], $data['content']];
			
			if ($this->userModel->insertPostData($insert)) {
				$this->setFlash('messageSuccess', 'Your record has been insert successfully!');
				$this->redirect("user/articleManage");
			}
		}
		else {
			$this->setFlash('messageWarning', 'Please correct errors in the form!');
			$this->view("article_add", $data);
		}
	}
	
	public function articleEditMethod($id) {
		$user_id = $this->getSession('userId');
		$result = $this->userModel->editPostData($id, $user_id);
		$arrImages = $this->userModel->getImages($user_id);
		
		$data = [
			'data'          => $result,
			'images'        => $arrImages,
			'errorHeader'   => '',
			'errorContent'  => ''
		];
		
		$this->view("article_edit", $data);
	}
	
	public function articleUpdateMethod() {
		 $id = $this->input('dbm_idpost');
		 $user_id = $this->getSession('userId');
		 $result = $this->userModel->editPostData($id, $user_id);
		 
		 $data = [
			'id_post'       => $this->input('dbm_idpost'),
			'header'           => $this->input('dbm_header'),
			'content'          => $this->inputHtml('dbm_content'),
			'data'             => $result,
			'errorHeader'      => '',
			'errorContent'     => ''
		];
		
		if (empty($data['header'])) {
			$data['errorHeader'] = "Header is required!";
		}
		if (empty($data['content'])) {
			$data['errorContent'] = "Content is required!";
		}
		
		if (empty($data['errorHeader']) && empty($data['errorContent'])) {
			$update = [$data['header'], $data['content'], $data['id_post'], $user_id];
			
			if ($this->userModel->updatePostData($update)) {
				$this->setFlash('messageSuccess', 'Your record has been updated successfully!');
				$this->redirect("user/articleManage");
			}
		}
		else {
			$this->setFlash('messageWarning', 'Please correct any errors in the form!');
			$this->view("article_edit", $data);
		}
    }
	
	public function articleDeleteMethod($id) {
		$user_id = $this->getSession('userId');
		
		if ($this->userModel->deletePostData($id, $user_id)) {
			$this->setFlash('messageDanger', 'Your record has been deleted!');
			$this->redirect('user/articleManage');
		}
    }
	
	public function imageUploadMethod($id) {
		$user_id = $this->getSession('userId');
		$result = $this->userModel->editPostData($id, $user_id);
		$arrImages = $this->userModel->getImages($user_id);
		$arrFile = $this->fileUpload();
		
		if (isset($arrFile['filename'])) {
			$insert = [$user_id, $arrFile['filename']];
			
			if ($this->userModel->insertImage($insert)) {
				$this->setFlash('alert-success', 'Image has been upload and save successfully!');
			}
			else {
				$this->setFlash('alert-danger', 'Database query error for image name: '.$arrFile['filename'].'. Save the information with the image name and inform Admin about the error!');
			}
		}
		else {
			$this->setFlash($arrFile['status'], $arrFile['message']);
		}
		
		$data = [
			'data'          => $result,
			'images'        => $arrImages,
			'errorHeader'   => '',
			'errorContent'  => ''
		];
		
		$this->view("article_edit", $data);
	}
	
}
?>
