<?php 
/**
 * DbM Framework (PHP MVC Simple CMS)
 * All code copyright Design by Malina
 * DbM: www.dbm.org.pl
 */

// error_reporting(0);

class frameworkClass {
	
	// View Page Template
	public function view($viewName, $data = []) {
		if (file_exists("../application/views/" . $viewName . ".php")) {
			require_once("../application/views/$viewName.php");
		}
		else {
			echo '<div class="alert-small alert-danger"> ERROR: Sorry application view '.$viewName.'.php file not found!</div>';
		}
	}
	
	// Model SQL Database
	public function model($modelName) {
		if (file_exists("../application/models/" . $modelName . ".php")) {
			require_once "../application/models/$modelName.php";
			return new $modelName;
		}
		else {
			echo '<div class="alert-small alert-danger">ERROR: Sorry application model '.$modelName.'.php file not found!</div>';
		}
	}
	
	// Helper functions
	public function helper($helperName) {
		if (file_exists("../system/functions/" . $helperName . ".php")) {
			require_once("../system/functions/" . $helperName . ".php");
		}
		else {
			echo '<div class="alert-small alert-danger">ERROR: Sorry system function '.$helperName.'.php file not found!</div>';
		}
	}
	
	// Input form data
	public function input($inputName) {
		if ($_SERVER['REQUEST_METHOD'] == "POST" || $_SERVER['REQUEST_METHOD'] == 'post') {
			return trim(strip_tags($_POST[$inputName]));
		}
		else if ($_SERVER['REQUEST_METHOD'] == 'GET' || $_SERVER['REQUEST_METHOD'] == 'get') {
			return trim(strip_tags($_GET[$inputName]));
		}
	}
	
	// Set session
	public function setSession($sessionName, $sessionValue) {
		if (!empty($sessionName) && !empty($sessionValue)){
			$_SESSION[$sessionName] = $sessionValue;
		}
	}
	
	// Get session
	public function getSession($sessionName) {
		if (isset($_SESSION['userId']) && !empty($sessionName)) { // ??? dbmUserId
			return $_SESSION[$sessionName];
		}
	}
	
	// Unset session
	public function unsetSession($sessionName) {
		if (!empty($sessionName)) {
			unset($_SESSION[$sessionName]);
		}
	}
	
	// Destroy whole sessions
	public function destroy() {
		session_destroy();
	}
	
	// Set flash message
	public function setFlash($sessionName, $msg) {
		if (!empty($sessionName) && !empty($msg)) {
			$_SESSION[$sessionName] = $msg;
		}
	}
	
	// Show flash message
	public function flash($sessionName, $className) {
		if (!empty($sessionName) && !empty($className) && isset($_SESSION[$sessionName])) {
			$msg = $_SESSION[$sessionName];
			echo '<div class="'.$className.'">'.$msg.'</div>'.PHP_EOL;
			unset($_SESSION[$sessionName]);
		}
	}
	
	// Redirect to location
	public function redirect($path) {
		header("location:" . ROOTPATH . $path);
	}
	
	// Input/save HTML width form to database (function related to readContent() in application.php)
	public function inputHtml($inputName) {
		if ($_SERVER['REQUEST_METHOD'] == "POST" || $_SERVER['REQUEST_METHOD'] == 'post') {
			return trim(htmlspecialchars($_POST[$inputName], ENT_QUOTES));
		}
		else if ($_SERVER['REQUEST_METHOD'] == 'GET' || $_SERVER['REQUEST_METHOD'] == 'get') {
			return trim(htmlspecialchars($_GET[$inputName], ENT_QUOTES));
		}
	}
	
	public function fileUpload() {
		if(isset($_POST["submit"])) {
			
			// Set image placement folder
			$target_dir = "upload/";
			$dir_oryginal = "oryginal/";
			$dir_photo = "photo/";
			// Allowed file types
			$allowd_file_ext = array("jpg", "jpeg");
			// Imge required
			$max_size = 6291456; // image max size 6MB (1MB = 1048576 KB)
			$max_length = 30; // image max name lenght (DB 50: 30+1+13+1+2=47)
			$min_width = 800; // image min size for check (in pixels)
			$max_width = 1280; // image max size for resize (in pixels)
		
			// Process
			$imageFullName = basename($_FILES["fileUpload"]["name"]);
			$imageName = pathinfo($imageFullName, PATHINFO_FILENAME);
			$imageName = str_replace([' ','_'],'-', preg_replace('/\s+/', '-', $imageName));
			$imageExt = strtolower(pathinfo($imageFullName, PATHINFO_EXTENSION));
			$imageExt = str_replace('jpeg','jpg',$imageExt);
			$safeFilename = transliterator_transliterate('Any-Latin; Latin-ASCII; [^A-Za-z0-9-] remove; Lower()', $imageName);
			$newFilename = $safeFilename.'_'.uniqid().'.'.$imageExt;
			$target_oryginal = $target_dir.$dir_oryginal.$newFilename;
			$target_photo = $target_dir.$dir_photo.$newFilename;
        
			if (!file_exists($_FILES["fileUpload"]["tmp_name"])) {
				$resMessage = array(
					"status" => "alert-danger",
					"message" => "Please select image to upload!"
			);
			} else if ($_FILES["fileUpload"]["size"] > $max_size) { 
				$resMessage = array(
					"status" => "alert-danger",
					"message" => "File is too large. File size should be less than $max_size kilobytes!"
				);
			} else if (strlen($imageName) > $max_length) {
				$resMessage = array(
					"status" => "alert-danger",
					"message" => "The photo name is too long, maximum $max_length characters!"
				); 
			} else if (!in_array($imageExt, $allowd_file_ext)) {
				$resMessage = array(
					"status" => "alert-danger",
					"message" => "Allowed file formats .jpg, .jpeg!"
				);
			} else if (file_exists($target_photo)) {
				$resMessage = array(
					"status" => "alert-danger",
					"message" => "File already exists. An exception has occurred, please try again!"
				);
			} else {
				if (move_uploaded_file($_FILES["fileUpload"]["tmp_name"], $target_oryginal)) {

					$original_dimensions = getimagesize($target_oryginal);
					$width = $original_dimensions[0];
					$height = $original_dimensions[1];
				
					if ($width < $min_width) {
						unlink($target_oryginal);
					
						$resMessage = array(
							"status" => "alert-danger",
							"message" => "Uploaded file is too small. Minimum width is $min_width px!"
						);
					}
					else {
						$ratio = $original_dimensions[0]/$original_dimensions[1];
						$aspect = $width/$max_width;
					
						if ($ratio < 1) { $new_width = ceil($max_width*$ratio); $new_height = $max_width; }
						else { $new_width = $max_width; $new_height = ceil($height/$aspect); }
					
						$small = imagecreatetruecolor($new_width, $new_height);
						$source = imagecreatefromjpeg($target_oryginal);
						imagecopyresized($small, $source, 0, 0, 0, 0, $new_width, $new_height, $width, $height);
						imagejpeg($small, $target_photo);
					
						unlink($target_oryginal);

						$resMessage = array(
							"status" => "alert-success",
							"message" => "Image uploaded successfully!",
							"filename" => "$newFilename"
						);
					}
				} 
				else {
					$resMessage = array(
						"status" => "alert-danger",
						"message" => "Image coudn't be uploaded!"
					);
				}
			}
			
			return $resMessage;
		}
	}
	
}
?>